@@ -16,12 +16,11 @@ from .handlers import (
     TextHandler,
 )
 from .keyboards import InlineKeyboard
-from .loader import app
-from .texts import Texts
+from .loader import app, texts
 
 __all__ = [
     "app",
-    "Texts",
+    "texts",
     "InlineKeyboard",
     "UrlButton",
     "CallbackButton",
