@@ -11,9 +11,10 @@ class QueryHandler(ext.CallbackQueryHandler[PTBContext]):
         self._callback = callback
         super().__init__(self.handle, self._filter)
 
-    async def handle(self, update: Update, _context: PTBContext) -> None:
-        context = QueryContext(_context, update)
-        await self._callback(context)
+    async def handle(self, update: Update, context: PTBContext) -> None:
+        _context = QueryContext(context, update)
+        await self._callback(_context)
+        await _context.answer()
 
     def _filter(self, callback_data: object) -> bool:
         return callback_data == self._button.callback_data
