@@ -2,6 +2,7 @@ from .app import App
 from .context import Callback, Context, ContextT
 from .env import env
 from .ptb_types import PTBCallback, PTBContext, PTBHandler, ReplyMarkup
+from .texts import Texts
 from .types import (
     Bot,
     Chat,
@@ -14,6 +15,7 @@ from .types import (
 __all__ = [
     "App",
     "env",
+    "Texts",
     "Callback",
     "Context",
     "ContextT",
