@@ -1,5 +1,5 @@
 from collections.abc import Awaitable, Callable
-from typing import TypeVar
+from typing import Any, TypeVar
 
 import telegram
 
@@ -32,4 +32,4 @@ class Context:
 
 
 ContextT = TypeVar("ContextT", bound=Context)
-Callback = Callable[[ContextT], Awaitable[None]]
+Callback = Callable[[ContextT], Awaitable[Any]]  # TODO
