@@ -1,4 +1,5 @@
 from collections.abc import Awaitable, Callable
+from typing import Any
 
 from telegram import (
     ForceReply,
@@ -11,6 +12,6 @@ from telegram import (
 
 PTBContext = ext.ContextTypes.DEFAULT_TYPE
 PTBHandler = ext.BaseHandler[Update, PTBContext]  # type: ignore[misc]
-PTBCallback = Callable[[Update, PTBContext], Awaitable[None]]
+PTBCallback = Callable[[Update, PTBContext], Awaitable[Any]]
 KeyboardMarkup = ReplyKeyboardMarkup | InlineKeyboardMarkup
 ReplyMarkup = KeyboardMarkup | ReplyKeyboardRemove | ForceReply
