@@ -35,3 +35,13 @@ class Message(TelegramObject):
             text,
             reply_markup=markup,  # type: ignore[arg-type]
         )
+
+    async def edit(
+        self,
+        text: str,
+        markup: ReplyMarkup | None = None,
+    ) -> telegram.Message | bool:
+        return await self.raw.edit_text(
+            text,
+            reply_markup=markup,  # type: ignore[arg-type]
+        )
